Interface: DatasetControllerChartComponent | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: DatasetControllerChartComponent

## # Hierarchy

- `ChartComponent`

  ↳ `DatasetControllerChartComponent`

## # Properties

### # defaultRoutes

• `Optional` defaultRoutes: `Object`

#### # Index signature

▪ [property: `string`]: `string`

#### # Inherited from

ChartComponent.defaultRoutes

#### # Defined in

index.esm.d.ts:1414
(opens new window)

### # defaults

• defaults: `Object`

#### # Type declaration

Name | Type
--- | ---
`dataElementType?` | `string` | `false`
`datasetElementType?` | `string` | `false`

#### # Overrides

ChartComponent.defaults

#### # Defined in

index.esm.d.ts:651
(opens new window)

### # id

• id: `string`

#### # Inherited from

ChartComponent.id

#### # Defined in

index.esm.d.ts:1412
(opens new window)

## # Methods

### # afterRegister

▸ `Optional` afterRegister(): `void`

#### # Returns

`void`

#### # Inherited from

ChartComponent.afterRegister

#### # Defined in

index.esm.d.ts:1417
(opens new window)

### # afterUnregister

▸ `Optional` afterUnregister(): `void`

#### # Returns

`void`

#### # Inherited from

ChartComponent.afterUnregister

#### # Defined in

index.esm.d.ts:1419
(opens new window)

### # beforeRegister

▸ `Optional` beforeRegister(): `void`

#### # Returns

`void`

#### # Inherited from

ChartComponent.beforeRegister

#### # Defined in

index.esm.d.ts:1416
(opens new window)

### # beforeUnregister

▸ `Optional` beforeUnregister(): `void`

#### # Returns

`void`

#### # Inherited from

ChartComponent.beforeUnregister

#### # Defined in

index.esm.d.ts:1418
(opens new window)